require 'harvest/version'

require 'thor'

require 'harvest/vcs'
require 'harvest/issue_tracker'
require 'harvest/credentials_manager'
require 'harvest/time_logger'

module Harvest
  class CLI < Thor
    desc "Setup the gem", "Stores config variables"
    def init
      current_project = Harvest::Vcs.current_project
      raise 'NO Git repo initialized' if current_project.empty?
      
      credential_manager = Harvest::CredentialsManager.new(current_project)
      credential_manager.request
      credential_manager.save
    end
    
    desc "Start Harvest Timer", "Start tracking of current branch"
    def start
      current_project = Harvest::Vcs.current_project
      
      config = Harvest::CredentialsManager.new(current_project).read[current_project]
      
      vcs_instance = Harvest::Vcs.new(config['jira']['project_code'])
      
      return if vcs_instance.ticket_id.nil?
      
      issue_tracker = Harvest::IssueTracker.new(
        config: config['jira'],
        task_identifier: vcs_instance.ticket_id
      )
      issue_tracker.fetch_issue

      Harvest::TimeLogger.new(config['harvest']).log(
        task_title: issue_tracker.task_title,
        task_url: issue_tracker.task_url
      )
    end
  end
end
