require 'rest-client'

module Harvest
  class IssueTracker
    attr_reader :config, :task_identifier, :task_details
    
    def initialize(config: , task_identifier:)
      @config = config
      @task_identifier = task_identifier
    end
    
    def fetch_issue
      response = RestClient::Request.new(
        method: :get,
        url: rest_api_url,
        user: config['username'],
        password: config['access_token'],
        headers: { accept: :json, content_type: :json }
      ).execute
  
      @task_details = JSON.parse(response.body)
    end
    
    def task_title
      task_details['fields']['summary']
    end

    def task_id
      "#{project_code}-#{task_identifier}"
    end
    
    def task_url
      "#{project_url}/browse/#{task_id}"
    end
    
    private
    
    def rest_api_url
      "#{project_url}/rest/api/latest/issue/#{task_id}"
    end
    
    def project_code
      config['project_code']
    end

    def project_url
      config['project_url']
    end
  end
end
