require 'rest-client'
require 'json'

module Harvest
  class TimeLogger
    BASE_URL = 'https://api.harvestapp.com/v2'.freeze
    DEFAULT_USER_AGENT = 'Oozou Harvest CLI (abhinav@oozou.com)'.freeze
    WEB_DEVELOPMENT_TASK_ID = 10740736
    
    attr_reader :config
    
    def initialize(config)
      @config = config
      config['task_id'] ||= WEB_DEVELOPMENT_TASK_ID
    end

    def projects
      response = RestClient::Request.execute(
        method: :get,
        url: "#{BASE_URL}/users/me/project_assignments",
        headers: headers
      )
  
      JSON.parse(response.body)['project_assignments'].map do |project_assignment|
        {
          name: project_assignment['project']['name'],
          id: project_assignment['project']['id']
        }
      end
    end
    
    def log(task_title:, task_url: nil)
      RestClient.post(
        "#{BASE_URL}/time_entries",
        time_log_payload(task_title, task_url).to_json,
        headers
      )
    end
    
    private
    
    def headers
      {
        "Content-Type" => "application/json",
        "User-Agent"=> DEFAULT_USER_AGENT,
        "Authorization" => "Bearer #{config['access_token']}",
        "Harvest-Account-Id" => config['account_id']
      }
    end
    
    def time_log_payload(task_title, task_url)
      {
        project_id: config['project_id'],
        task_id: config['task_id'],
        spent_date: Date.today.strftime('%Y-%m-%d'),
        notes: task_title,
        external_reference: {
          permalink: task_url
        }
      }
    end
  end
end
